@@ -28,15 +28,15 @@ from tqdm import tqdm
 from .canonicalize import to_bel_script
 from .constants import get_cache_connection
 from .examples import braf_graph, egf_graph, homology_graph, sialic_acid_graph, statin_graph
+from .exceptions import BELParserWarning
 from .io import (
     from_bel_script, from_pickle, load, to_bel_commons, to_edgelist, to_graphml, to_gsea, to_neo4j,
-    to_nodelink_file, to_pickle, to_sif, to_tsv,
+    to_nodelink_file, to_pickle, to_sif, to_triples_file,
 )
 from .io.bel_commons_client import _get_host, _get_password, _get_user
 from .manager import Manager
 from .manager.database_io import to_database
 from .manager.models import Edge, Namespace, Node
-from .parser.exc import BELParserWarning
 from .struct import get_unused_annotations, get_unused_list_annotation_values, get_unused_namespaces
 from .struct.graph import BELGraph, WarningTuple
 from .utils import get_corresponding_pickle_path
@@ -105,6 +105,26 @@ graph_argument = click.argument(
     callback=lambda _, __, path: load(path),
 )
 
+LOG_FMT = '%(asctime)s %(levelname)-8s %(message)s'
+LOG_DATEFMT = '%Y-%m-%d %H:%M:%S'
+
+
+def _debug_callback(_ctx, _param, value):
+    if not value:
+        logging.basicConfig(level=logging.WARNING, format=LOG_FMT, datefmt=LOG_DATEFMT)
+    elif value == 1:
+        logging.basicConfig(level=logging.INFO, format=LOG_FMT, datefmt=LOG_DATEFMT)
+    else:
+        logging.basicConfig(level=logging.DEBUG, format=LOG_FMT, datefmt=LOG_DATEFMT)
+
+
+verbose_option = click.option(
+    '-v', '--verbose',
+    count=True,
+    callback=_debug_callback,
+    expose_value=False,
+)
+
 
 @with_plugins(iter_entry_points('pybel.cli_plugins'))
 @click.group(help="PyBEL CLI on {}".format(sys.executable))
@@ -117,6 +137,15 @@ def main(ctx, connection):
     ctx.obj.bind()  # add the engine to the metadata and query property to the session
 
 
+@main.command()
+@click.argument('text')
+@click.option('--pprint', is_flag=True)
+def parse(text: str, pprint: bool):
+    """Parse a single BEL statement and pring JSON output."""
+    from .parser.parse_bel import parse as _parse
+    click.echo(json.dumps(_parse(text), indent=2 if pprint else None))
+
+
 @main.command()
 @click.argument('path')
 @click.option('--allow-naked-names', is_flag=True, help="Enable lenient parsing for naked names")
@@ -127,18 +156,14 @@ def main(ctx, connection):
 @click.option('-r', '--required-annotations', multiple=True, help='Specify multiple required annotations')
 @click.option('--upgrade-urls', is_flag=True)
 @click.option('--skip-tqdm', is_flag=True)
-@click.option('-v', '--verbose', is_flag=True)
+@verbose_option
 @click.pass_obj
 def compile(
     manager, path, allow_naked_names, disallow_nested, disallow_unqualified_translocations,
-    no_identifier_validation, no_citation_clearing, required_annotations, upgrade_urls,
-    skip_tqdm, verbose,
+    no_identifier_validation, no_citation_clearing, required_annotations, upgrade_urls, skip_tqdm,
 ):
     """Compile a BEL script to a graph."""
-    if verbose:
-        logging.basicConfig(level=logging.DEBUG)
-        logger.setLevel(logging.DEBUG)
-        logger.debug('using connection: %s', manager.engine.url)
+    logger.debug('using connection: %s', manager.engine.url)
 
     click.secho('Compilation', fg='red', bold=True)
     if skip_tqdm:
@@ -146,7 +171,7 @@ def compile(
     graph = from_bel_script(
         path,
         manager=manager,
-        use_tqdm=(not (skip_tqdm or verbose)),
+        use_tqdm=(not skip_tqdm),
         disallow_nested=disallow_nested,
         allow_naked_names=allow_naked_names,
         disallow_unqualified_translocations=disallow_unqualified_translocations,
@@ -259,7 +284,7 @@ def serialize(graph: BELGraph, tsv, edgelist, sif, gsea, graphml, nodelink, bel)
     """Serialize a graph to various formats."""
     if tsv:
         logger.info('Outputting TSV to %s', tsv)
-        to_tsv(graph, tsv)
+        to_triples_file(graph, tsv)
 
     if edgelist:
         logger.info('Outputting edgelist to %s', edgelist)
