@@ -23,28 +23,24 @@ def get_cache_connection() -> str:
 PYBEL_CONTEXT_TAG = 'pybel_context'
 PYBEL_AUTOEVIDENCE = 'Automatically added by PyBEL'
 
-#: The default namespace given to entities in the BEL language
-BEL_DEFAULT_NAMESPACE = 'bel'
-
-CITATION_TYPE_BOOK = 'Book'
-CITATION_TYPE_PUBMED = 'PubMed'
-CITATION_TYPE_PMC = 'PubMed Central'
-CITATION_TYPE_JOURNAL = 'Journal'
-CITATION_TYPE_ONLINE = 'Online Resource'
-CITATION_TYPE_URL = 'URL'
-CITATION_TYPE_DOI = 'DOI'
-CITATION_TYPE_OTHER = 'Other'
-#: The valid citation types
-#: .. seealso:: https://wiki.openbel.org/display/BELNA/Citation
+CITATION_TYPE_BOOK = 'book'
+CITATION_TYPE_PUBMED = 'pubmed'
+CITATION_TYPE_PMC = 'pmc'
+CITATION_TYPE_URL = 'url'
+CITATION_TYPE_DOI = 'doi'
+CITATION_TYPE_OTHER = 'other'
 CITATION_TYPES = {
-    CITATION_TYPE_BOOK: None,
-    CITATION_TYPE_PUBMED: 'pmid',
-    CITATION_TYPE_PMC: 'pmc',
-    CITATION_TYPE_JOURNAL: None,
-    CITATION_TYPE_ONLINE: None,
-    CITATION_TYPE_URL: None,
-    CITATION_TYPE_DOI: 'doi',
-    CITATION_TYPE_OTHER: None,
+    CITATION_TYPE_BOOK,
+    CITATION_TYPE_PUBMED,
+    CITATION_TYPE_PMC,
+    CITATION_TYPE_URL,
+    CITATION_TYPE_DOI,
+    CITATION_TYPE_OTHER,
+}
+CITATION_NORMALIZER = {
+    'pubmed central': 'pmc',
+    'pmid': 'pubmed',
+    'online resource': 'url',
 }
 
 NAMESPACE_DOMAIN_BIOPROCESS = 'BiologicalProcess'
@@ -60,13 +56,6 @@ NAMESPACE_DOMAIN_TYPES = {
     NAMESPACE_DOMAIN_OTHER,
 }
 
-#: Represents the key for the citation type in a citation dictionary
-CITATION_DB = 'db'
-#: Represents the key for the citation reference in a citation dictionary
-CITATION_IDENTIFIER = 'db_id'
-
-#: Represents the key for the optional PyBEL citation title entry in a citation dictionary
-CITATION_DB_NAME = 'db_name'
 #: Represents the key for the citation date in a citation dictionary
 CITATION_DATE = 'date'
 #: Represents the key for the citation authors in a citation dictionary
@@ -83,12 +72,13 @@ CITATION_PAGES = 'pages'
 CITATION_FIRST_AUTHOR = 'first'
 #: Represents the key for the optional PyBEL citation last author entry in a citation dictionary
 CITATION_LAST_AUTHOR = 'last'
+#: Represents the type of article (Journal Article, Review, etc.)
+CITATION_ARTICLE_TYPE = 'article_type'
 
 # Used during BEL parsing
 
 MODIFIER = 'modifier'
 EFFECT = 'effect'
-TARGET = 'target'
 FROM_LOC = 'fromLoc'
 TO_LOC = 'toLoc'
 
@@ -252,16 +242,20 @@ rev_abundance_labels = {
 RELATION = 'relation'
 #: The key for an internal edge data dictionary for the citation dictionary
 CITATION = 'citation'
+CITATION_DB = NAMESPACE  # for backwards compatibility
+CITATION_IDENTIFIER = IDENTIFIER  # for backwards compatibility
 #: The key for an internal edge data dictionary for the evidence string
 EVIDENCE = 'evidence'
 #: The key for an internal edge data dictionary for the annotations dictionary
 ANNOTATIONS = 'annotations'
-#: The key for free annotations
-FREE_ANNOTATIONS = 'free_annotations'
-#: The key for an internal edge data dictionary for the subject modifier dictionary
-SUBJECT = 'subject'
-#: The key for an internal edge data dictionary for the object modifier dictionary
-OBJECT = 'object'
+SOURCE = 'source'
+SUBJECT = SOURCE  # for backwards compatibility
+TARGET = 'target'
+OBJECT = TARGET  # for backwards compatibility
+#: The key for an internal edge data dictionary for the source modifier dictionary
+SOURCE_MODIFIER = 'source_modifier'
+#: The key for an internal edge data dictionary for the target modifier dictionary
+TARGET_MODIFIER = 'target_modifier'
 #: The key or an internal edge data dictionary for the line number
 LINE = 'line'
 #: The key representing the hash of the other
@@ -273,8 +267,8 @@ PYBEL_EDGE_DATA_KEYS = {
     CITATION,
     EVIDENCE,
     ANNOTATIONS,
-    SUBJECT,
-    OBJECT,
+    SOURCE_MODIFIER,
+    TARGET_MODIFIER,
 }
 
 #: The group of all PyBEL-specific keys for edge data dictionaries, not used for hashing.
@@ -311,6 +305,8 @@ CAUSES_NO_CHANGE = 'causesNoChange'
 #: A BEL relationship
 REGULATES = 'regulates'
 #: A BEL relationship
+DIRECTLY_REGULATES = 'directlyRegulates'
+#: A BEL relationship
 BINDS = 'binds'
 #: A BEL relationship
 CORRELATION = 'correlation'
@@ -345,14 +341,16 @@ PART_OF = 'partOf'
 CAUSAL_INCREASE_RELATIONS = {INCREASES, DIRECTLY_INCREASES}
 #: A set of all causal relationships that have a decreasing effect
 CAUSAL_DECREASE_RELATIONS = {DECREASES, DIRECTLY_DECREASES}
+#: A set of all causal relationships that have an inderminate polarity
+CAUSAL_APOLAR_RELATIONS = {REGULATES, DIRECTLY_REGULATES}
 #: A set of direct causal relations
-DIRECT_CAUSAL_RELATIONS = {DIRECTLY_DECREASES, DIRECTLY_INCREASES}
+DIRECT_CAUSAL_RELATIONS = {DIRECTLY_DECREASES, DIRECTLY_INCREASES, DIRECTLY_REGULATES}
 #: A set of direct causal relations
 INDIRECT_CAUSAL_RELATIONS = {DECREASES, INCREASES, REGULATES}
 #: A set of causal relationships that are polar
 CAUSAL_POLAR_RELATIONS = CAUSAL_INCREASE_RELATIONS | CAUSAL_DECREASE_RELATIONS
 #: A set of all causal relationships
-CAUSAL_RELATIONS = CAUSAL_INCREASE_RELATIONS | CAUSAL_DECREASE_RELATIONS | {REGULATES}
+CAUSAL_RELATIONS = CAUSAL_INCREASE_RELATIONS | CAUSAL_DECREASE_RELATIONS | CAUSAL_APOLAR_RELATIONS
 
 APOLAR_CORRELATIVE_RELATIONS = {
     CORRELATION,
@@ -430,6 +428,8 @@ GRAPH_METADATA = 'document_metadata'
 GRAPH_NAMESPACE_URL = 'namespace_url'
 GRAPH_NAMESPACE_PATTERN = 'namespace_pattern'
 GRAPH_ANNOTATION_URL = 'annotation_url'
+GRAPH_ANNOTATION_MIRIAM = 'annotation_miriam'
+GRAPH_ANNOTATION_CURIE = 'annotation_curie'
 GRAPH_ANNOTATION_PATTERN = 'annotation_pattern'
 GRAPH_ANNOTATION_LIST = 'annotation_list'
 GRAPH_WARNINGS = 'warnings'
