@@ -19,12 +19,13 @@ import requests
 from networkx.utils import open_file
 from pyparsing import ParseException
 
+from .. import constants as pc
 from ..constants import (
-    ANNOTATIONS, CITATION, EVIDENCE, METADATA_AUTHORS, METADATA_CONTACT,
+    ANNOTATIONS, CITATION, EVIDENCE, GRAPH_ANNOTATION_URL, GRAPH_NAMESPACE_URL, METADATA_AUTHORS, METADATA_CONTACT,
     METADATA_INSERT_KEYS, METADATA_LICENSES, RELATION, UNQUALIFIED_EDGES,
 )
+from ..exceptions import NakedNameWarning, UndefinedNamespaceWarning
 from ..parser import BELParser
-from ..parser.exc import NakedNameWarning, UndefinedNamespaceWarning
 from ..struct import BELGraph
 from ..version import get_version
 
@@ -198,6 +199,8 @@ def from_cbn_jgif(graph_jgif_dict):
     """
     graph_jgif_dict = map_cbn(graph_jgif_dict)
 
+    graph_jgif_dict['graph'][GRAPH_NAMESPACE_URL] = NAMESPACE_URLS
+    graph_jgif_dict['graph'][GRAPH_ANNOTATION_URL] = ANNOTATION_URLS
     graph_jgif_dict['graph']['metadata'].update({
         METADATA_AUTHORS: 'Causal Biological Networks Database',
         METADATA_LICENSES: """
@@ -219,14 +222,10 @@ def from_cbn_jgif(graph_jgif_dict):
     })
 
     graph = from_jgif(graph_jgif_dict)
-
-    graph.namespace_url.update(NAMESPACE_URLS)
-    graph.annotation_url.update(ANNOTATION_URLS)
-
     return graph
 
 
-def from_jgif(graph_jgif_dict, parser_kwargs: Optional[Mapping[str, Any]] = None):
+def from_jgif(graph_jgif_dict, parser_kwargs: Optional[Mapping[str, Any]] = None):  # noqa:C901
     """Build a BEL graph from a JGIF JSON object.
 
     :param dict graph_jgif_dict: The JSON object representing the graph in JGIF format
@@ -246,6 +245,10 @@ def from_jgif(graph_jgif_dict, parser_kwargs: Optional[Mapping[str, Any]] = None
             if key in metadata:
                 graph.document[key] = metadata[key]
 
+    for k in (GRAPH_ANNOTATION_URL, GRAPH_NAMESPACE_URL):
+        if k in root:
+            graph.graph[k] = root[k]
+
     parser = BELParser(graph, namespace_to_pattern=NAMESPACE_TO_PATTERN)
     parser.bel_term.addParseAction(parser.handle_term)
 
@@ -307,10 +310,13 @@ def from_jgif(graph_jgif_dict, parser_kwargs: Optional[Mapping[str, Any]] = None
                     continue
 
                 parser.control_parser.clear()
-                parser.control_parser.citation_db = citation['type'].strip()
+                citation_namespace = citation['type'].lower().strip()
+                citation_namespace = pc.CITATION_NORMALIZER.get(citation_namespace, citation_namespace)
+                parser.control_parser.citation_db = citation_namespace
                 parser.control_parser.citation_db_id = citation['id'].strip()
                 parser.control_parser.evidence = summary_text
-                parser.control_parser.annotations.update(evidence[EXPERIMENT_CONTEXT])
+                annotations = parser.graph._clean_annotations(evidence[EXPERIMENT_CONTEXT])
+                parser.control_parser.annotations.update(annotations)
 
                 try:
                     parser.parseString(bel_statement, line_number=i)
