@@ -6,12 +6,11 @@ Under the hood, PyBEL caches namespace and annotation files for quick recall on
 enable this option, but can specify a database location if they choose.
 """
 
-import json
 import logging
 import time
-from itertools import chain
-from typing import Any, Iterable, List, Mapping, Optional, Set, Tuple
+from typing import Iterable, List, Mapping, Optional, Set, Tuple
 
+import pandas as pd
 import requests
 import sqlalchemy
 from sqlalchemy import and_, exists, func
@@ -29,14 +28,11 @@ from .models import (
 from .query_manager import QueryManager
 from .utils import extract_shared_optional, extract_shared_required, update_insert_values
 from ..constants import (
-    ANNOTATIONS, BEL_DEFAULT_NAMESPACE, CITATION, CITATION_DB, CITATION_IDENTIFIER, CITATION_TYPE_PUBMED, EVIDENCE,
-    METADATA_INSERT_KEYS, OBJECT, RELATION, SUBJECT, UNQUALIFIED_EDGES, belns_encodings, get_cache_connection,
+    ANNOTATIONS, CITATION, CITATION_TYPE_PUBMED, EVIDENCE, IDENTIFIER, METADATA_INSERT_KEYS, NAMESPACE, RELATION,
+    SOURCE_MODIFIER, TARGET_MODIFIER, UNQUALIFIED_EDGES, belns_encodings, get_cache_connection,
 )
 from ..dsl import BaseConcept, BaseEntity
-from ..language import (
-    BEL_DEFAULT_NAMESPACE_URL, BEL_DEFAULT_NAMESPACE_VERSION, Entity, activity_mapping, compartment_mapping,
-    gmod_mappings, pmod_mappings,
-)
+from ..language import Entity
 from ..struct.graph import AnnotationsDict, BELGraph
 from ..struct.operations import union
 from ..typing import EdgeData
@@ -102,14 +98,6 @@ def _clean_bel_namespace_values(bel_resource):
     }
 
 
-def _normalize_url(graph: BELGraph, keyword: str) -> Optional[str]:  # FIXME move to utilities and unit test
-    """Normalize a URL for the BEL graph."""
-    if keyword == BEL_DEFAULT_NAMESPACE and BEL_DEFAULT_NAMESPACE not in graph.namespace_url:
-        return BEL_DEFAULT_NAMESPACE_URL
-
-    return graph.namespace_url.get(keyword)
-
-
 class NamespaceManager(BaseManager):
     """Manages BEL namespaces."""
 
@@ -152,26 +140,85 @@ class NamespaceManager(BaseManager):
         filt = and_(Namespace.keyword == keyword, Namespace.version == version)
         return self.session.query(Namespace).filter(filt).one_or_none()
 
-    def ensure_default_namespace(self) -> Namespace:
-        """Get or create the BEL default namespace."""
-        namespace = self.get_namespace_by_keyword_version(BEL_DEFAULT_NAMESPACE, BEL_DEFAULT_NAMESPACE_VERSION)
+    def _ensure_namespace_urls(
+        self,
+        urls: Iterable[str],
+        use_tqdm: bool = True,
+        is_annotation: bool = False,
+    ) -> List[Namespace]:
+        ext = 'belanno' if is_annotation else 'belns'
 
-        if namespace is None:
-            namespace = Namespace(
-                name='BEL Default Namespace',
-                keyword=BEL_DEFAULT_NAMESPACE,
-                version=BEL_DEFAULT_NAMESPACE_VERSION,
-                url=BEL_DEFAULT_NAMESPACE_URL,
-            )
+        rv = []
+        url_to_namespace = {}
+        url_to_values = {}
+        url_to_name_to_id = {}
 
-            for name in set(chain(pmod_mappings, gmod_mappings, activity_mapping, compartment_mapping)):
-                entry = NamespaceEntry(name=name, namespace=namespace)
-                self.session.add(entry)
+        tag = 'annotations' if is_annotation else 'namespaces'
 
-            self.session.add(namespace)
-            self.session.commit()
+        if use_tqdm:
+            urls = tqdm(urls, desc=f'downloading {tag}')
+        for url in urls:
+            result = self.get_namespace_by_url(url)
+            if result:
+                rv.append(result)
+                continue
+            bel_resource = get_bel_resource(url)
+            _clean_bel_namespace_values(bel_resource)
+            url_to_values[url] = bel_resource['Values']
 
-        return namespace
+            if is_annotation:
+                namespace_kwargs = _get_annotation_insert_values(bel_resource)
+            else:
+                namespace_kwargs = _get_namespace_insert_values(bel_resource)
+            result = url_to_namespace[url] = Namespace(url=url, **namespace_kwargs)
+            rv.append(result)
+            if url.endswith(f'-names.{ext}'):
+                mapping_url = url[:-len(f'-names.{ext}')] + f'.{ext}.mapping'
+                try:
+                    res = requests.get(mapping_url)
+                    res.raise_for_status()
+                except requests.exceptions.HTTPError:
+                    logger.warning('No mappings found for %s', url)
+                else:
+                    mappings = res.json()
+                    logger.debug('got %d mappings', len(mappings))
+                    url_to_name_to_id[url] = {v: k for k, v in res.json().items()}
+
+        self.session.add_all(url_to_namespace.values())
+        self.session.commit()
+
+        url_to_id = {url: namespace.id for url, namespace in url_to_namespace.items()}
+
+        if not url_to_values:
+            return rv
+
+        rows = []
+        it = url_to_values.items()
+        if use_tqdm:
+            it = tqdm(it, desc=f'making {tag} entry table')
+        if is_annotation:
+            for url, values in it:
+                for name, identifier in values.items():
+                    if not name:
+                        continue
+                    rows.append((url_to_id[url], name, None, identifier))  # TODO is this a fair assumption?
+        else:
+            for url, values in it:
+                name_to_id = url_to_name_to_id.get(url, {})
+                for name, encoding in values.items():
+                    if not name:
+                        continue
+                    rows.append((url_to_id[url], name, encoding, name_to_id.get(name)))
+
+        df = pd.DataFrame(rows, columns=['namespace_id', 'name', 'encoding', 'identifier'])
+        logger.info('preparing sql objects for %s', tag)
+        df.to_sql(NamespaceEntry.__tablename__, con=self.engine, if_exists='append', index=False)
+        logger.info('committing %s', tag)
+        start_commit_time = time.time()
+        self.session.commit()
+        logger.info('done committing %s after %.2f seconds', tag, time.time() - start_commit_time)
+
+        return rv
 
     def get_or_create_namespace(self, url: str) -> Namespace:
         """Insert the namespace file at the given location to the cache.
@@ -180,52 +227,7 @@ class NamespaceManager(BaseManager):
 
         :raises: pybel.resources.exc.ResourceError
         """
-        result = self.get_namespace_by_url(url)
-
-        if result is not None:
-            return result
-
-        t = time.time()
-
-        bel_resource = get_bel_resource(url)
-
-        _clean_bel_namespace_values(bel_resource)
-
-        values = bel_resource['Values']
-
-        namespace_insert_values = _get_namespace_insert_values(bel_resource)
-
-        name_to_id = {}
-        if url.endswith('-names.belns'):
-            mapping_url = url[:-len('-names.belns')] + '.belns.mapping'
-            try:
-                res = requests.get(mapping_url)
-                res.raise_for_status()
-            except requests.exceptions.HTTPError:
-                logger.warning('No mappings found for %s', url)
-            else:
-                mappings = res.json()
-                logger.debug('got %d mappings', len(mappings))
-                name_to_id.update({v: k for k, v in res.json().items()})
-
-        namespace = Namespace(
-            url=url,
-            **namespace_insert_values,
-        )
-
-        logger.debug('building NamespaceEntry instances')
-        namespace.entries = [
-            NamespaceEntry(name=name, encoding=encoding, identifier=name_to_id.get(name))
-            for name, encoding in values.items()
-        ]
-
-        self.session.add(namespace)
-
-        logger.debug('committing namespace')
-        self.session.commit()
-
-        logger.info('inserted namespace: %s (%d terms in %.2f seconds)', url, len(values), time.time() - t)
-        return namespace
+        return self._ensure_namespace_urls([url])[0]
 
     def get_namespace_by_keyword_pattern(self, keyword: str, pattern: str) -> Optional[Namespace]:
         """Get a namespace with a given keyword and pattern."""
@@ -264,6 +266,7 @@ class NamespaceManager(BaseManager):
         result = self.session.query(NamespaceEntry).join(Namespace).filter(entry_filter).all()
 
         if 0 == len(result):
+            logger.debug('could not find namespace entry for %s in url=%s', name, url)
             return
 
         if 1 < len(result):
@@ -320,58 +323,15 @@ class NamespaceManager(BaseManager):
 
         :raises: pybel.resources.exc.ResourceError
         """
-        result = self.get_namespace_by_url(url)
+        return self._ensure_namespace_urls([url], is_annotation=True)[0]
 
-        if result is not None:
-            return result
-
-        t = time.time()
-
-        bel_resource = get_bel_resource(url)
-
-        result = Namespace(
-            url=url,
-            is_annotation=True,
-            **_get_annotation_insert_values(bel_resource),
-        )
-        result.entries = [
-            NamespaceEntry(name=name, identifier=label)
-            for name, label in bel_resource['Values'].items()
-            if name
-        ]
-
-        self.session.add(result)
-        self.session.commit()
-
-        logger.info(
-            'inserted annotation: %s (%d terms in %.2f seconds)', url, len(bel_resource['Values']),
-            time.time() - t,
-        )
-
-        return result
-
-    def get_annotation_entry_names(self, url: str) -> Set[str]:
-        """Return a dict of annotations and their labels for the given annotation file.
-
-        :param url: the location of the annotation file
-        """
-        annotation = self.get_or_create_annotation(url)
-        return {
-            x.name
-            for x in self.session.query(NamespaceEntry.name).filter(NamespaceEntry.namespace == annotation)
-        }
-
-    def get_namespace_encoding(self, url: str) -> Mapping[str, str]:
-        annotation = self.get_or_create_annotation(url)
-        namespace_filter = NamespaceEntry.namespace == annotation
-        return dict(self.session.query(NamespaceEntry.name, NamespaceEntry.encoding).filter(namespace_filter))
-
-    def get_annotation_entries_by_names(self, url: str, names: Iterable[str]) -> List[NamespaceEntry]:
+    def get_annotation_entries_by_names(self, url: str, entities: Iterable[Entity]) -> List[NamespaceEntry]:
         """Get annotation entries by URL and names.
 
         :param url: The url of the annotation source
-        :param names: The names of the annotation entries from the given url's document
+        :param entities: The names of the annotation entries from the given url's document
         """
+        names = [e.identifier if isinstance(e, Entity) else e for e in entities]
         annotation_filter = and_(Namespace.url == url, NamespaceEntry.name.in_(names))
         return self.session.query(NamespaceEntry).join(Namespace).filter(annotation_filter).all()
 
@@ -570,7 +530,6 @@ class InsertManager(NamespaceManager, LookupManager):
         self,
         graph: BELGraph,
         use_tqdm: bool = True,
-        tqdm_kwargs: Optional[Mapping[str, Any]] = None,
     ) -> Network:
         """Insert a graph in the database and returns the corresponding Network model.
 
@@ -586,24 +545,13 @@ class InsertManager(NamespaceManager, LookupManager):
 
         t = time.time()
 
-        self.ensure_default_namespace()
-
         namespace_urls = graph.namespace_url.values()
-        if use_tqdm:
-            namespace_urls = tqdm(namespace_urls, **(tqdm_kwargs or {}))
-        for namespace_url in namespace_urls:
-            if use_tqdm:
-                namespace_urls.write('inserting namespace: {}'.format(namespace_url))
-            self.get_or_create_namespace(namespace_url)
-
+        self._ensure_namespace_urls(namespace_urls, use_tqdm=use_tqdm)
         for keyword, pattern in graph.namespace_pattern.items():
             self.ensure_regex_namespace(keyword, pattern)
 
         annotation_urls = graph.annotation_url.values()
-        if use_tqdm:
-            annotation_urls = tqdm(annotation_urls, desc='annotations')
-        for annotation_url in annotation_urls:
-            self.get_or_create_annotation(annotation_url)
+        self._ensure_namespace_urls(annotation_urls, use_tqdm=use_tqdm, is_annotation=True)
 
         network = Network(**{
             key: value
@@ -712,7 +660,7 @@ class InsertManager(NamespaceManager, LookupManager):
             elif EVIDENCE not in data or CITATION not in data:
                 continue
 
-            elif CITATION_DB not in data[CITATION] or CITATION_IDENTIFIER not in data[CITATION]:
+            elif NAMESPACE not in data[CITATION] or IDENTIFIER not in data[CITATION]:
                 continue
 
             else:
@@ -731,7 +679,7 @@ class InsertManager(NamespaceManager, LookupManager):
                 except Exception as e:
                     self.session.rollback()
                     logger.exception('error storing edge in database. edge data: %s', data)
-                    raise EdgeAddError(e, u, v, key, data) from e
+                    raise EdgeAddError(e, u, v, key, data)
                 else:
                     yield edge
 
@@ -739,9 +687,9 @@ class InsertManager(NamespaceManager, LookupManager):
     def _iter_from_annotations_dict(
         graph: BELGraph,
         annotations_dict: AnnotationsDict,
-    ) -> Iterable[Tuple[str, Set[str]]]:
+    ) -> Iterable[Tuple[str, Set[Entity]]]:
         """Iterate over the key/value pairs in this edge data dictionary normalized to their source URLs."""
-        for key, names in annotations_dict.items():
+        for key, entities in annotations_dict.items():
             if key in graph.annotation_url:
                 url = graph.annotation_url[key]
             elif key in graph.annotation_list:
@@ -752,7 +700,7 @@ class InsertManager(NamespaceManager, LookupManager):
             else:
                 raise ValueError('Graph resources does not contain keyword: {}'.format(key))
 
-            yield url, set(names)
+            yield url, set(entities)
 
     def _get_annotation_entries_from_data(self, graph: BELGraph, data: EdgeData) -> Optional[List[NamespaceEntry]]:
         """Get the annotation entries from an edge data dictionary."""
@@ -760,8 +708,8 @@ class InsertManager(NamespaceManager, LookupManager):
         if annotations_dict is None:
             return
         rv = []
-        for url, names in self._iter_from_annotations_dict(graph, annotations_dict=annotations_dict):
-            for entry in self.get_annotation_entries_by_names(url, names):
+        for url, entities in self._iter_from_annotations_dict(graph, annotations_dict=annotations_dict):
+            for entry in self.get_annotation_entries_by_names(url, entities):
                 rv.append(entry)
         return rv
 
@@ -777,8 +725,8 @@ class InsertManager(NamespaceManager, LookupManager):
         """Add a qualified edge to the network."""
         citation_dict = data[CITATION]
         citation = self.get_or_create_citation(
-            db=citation_dict[CITATION_DB],
-            db_id=citation_dict[CITATION_IDENTIFIER],
+            namespace=citation_dict[NAMESPACE],
+            identifier=citation_dict[IDENTIFIER],
         )
         evidence = self.get_or_create_evidence(citation, data[EVIDENCE])
         annotations = self._get_annotation_entries_from_data(graph, data)
@@ -850,7 +798,7 @@ class InsertManager(NamespaceManager, LookupManager):
             entry = self.get_namespace_entry(url, name)
 
             if entry is None:
-                logger.debug('skipping node with identifier %s: %s', url, name)
+                logger.debug('skipping node with entity %s:%s from url=%s', node.namespace, name, url)
                 return
 
             self.session.add(entry)
@@ -925,9 +873,9 @@ class InsertManager(NamespaceManager, LookupManager):
 
         edge = Edge(
             source=source,
-            source_modifier=data.get(SUBJECT),
+            source_modifier=data.get(SOURCE_MODIFIER),
             target=target,
-            target_modifier=data.get(OBJECT),
+            target_modifier=data.get(TARGET_MODIFIER),
             relation=relation,
             bel=bel,
             md5=md5,
@@ -946,30 +894,30 @@ class InsertManager(NamespaceManager, LookupManager):
     def get_or_create_citation(
         self,
         *,
-        db_id: str,
-        db: Optional[str] = None
+        identifier: str,
+        namespace: Optional[str] = None,
     ) -> Citation:
         """Create a citation if it does not exist, or return it if it does.
 
-        :param db_id: Identifier of the given citation (e.g. PubMed id)
-        :param db: Citation type (defaults to PubMed)
+        :param identifier: Identifier of the given citation (e.g. PubMed id)
+        :param namespace: Citation type (defaults to PubMed)
         """
-        if db is None:
-            db = CITATION_TYPE_PUBMED
+        if namespace is None:
+            namespace = CITATION_TYPE_PUBMED
 
-        citation_curie = '{}:{}'.format(db, db_id)
+        citation_curie = f'{namespace}:{identifier}'
         if citation_curie in self.curie_to_citation:
             citation = self.curie_to_citation[citation_curie]
             self.session.add(citation)
             return citation
 
-        citation = self.get_citation_by_reference(db, db_id)
+        citation = self.get_citation_by_reference(namespace, identifier)
 
         if citation is not None:
             self.curie_to_citation[citation_curie] = citation
             return citation
 
-        self.curie_to_citation[citation_curie] = citation = Citation(db=db, db_id=db_id)
+        self.curie_to_citation[citation_curie] = citation = Citation(db=namespace, db_id=identifier)
         self.session.add(citation)
         return citation
 
@@ -1031,7 +979,7 @@ class Manager(_Manager):
 
         :param connection: An RFC-1738 database connection string. If ``None``, tries to load from the
          environment variable ``PYBEL_CONNECTION`` then from the config file ``~/.config/pybel/config.json`` whose
-         value for ``PYBEL_CONNECTION`` defaults to :data:`pybel.constants.DEFAULT_CACHE_LOCATION`.
+         value for ``PYBEL_CONNECTION`` defaults to :data:`pybel.constants.DEFAULT_CACHE_CONNECTION`.
         :param engine: Optional engine to use. Must be specified with a session and no connection.
         :param session: Optional session to use. Must be specified with an engine and no connection.
         :param bool echo: Turn on echoing sql
