@@ -9,8 +9,8 @@ from .typing import EdgePredicate
 from .utils import part_has_modifier
 from ..graph import BELGraph
 from ...constants import (
-    ACTIVITY, ANNOTATIONS, ASSOCIATION, CAUSAL_RELATIONS, CITATION, CITATION_AUTHORS, CITATION_DB,
-    CITATION_TYPE_PUBMED, DEGRADATION, DIRECT_CAUSAL_RELATIONS, EVIDENCE, OBJECT, POLAR_RELATIONS, RELATION, SUBJECT,
+    ACTIVITY, ANNOTATIONS, ASSOCIATION, CAUSAL_RELATIONS, CITATION, CITATION_AUTHORS, DEGRADATION,
+    DIRECT_CAUSAL_RELATIONS, EVIDENCE, NAMESPACE, POLAR_RELATIONS, RELATION, SOURCE_MODIFIER, TARGET_MODIFIER,
     TRANSLOCATION,
 )
 from ...dsl import BaseEntity, BiologicalProcess, Pathology
@@ -18,9 +18,11 @@ from ...typing import EdgeData
 
 __all__ = [
     'edge_predicate',
-    'keep_edge_permissive',
+    'true_edge_predicate',
+    'false_edge_predicate',
     'has_provenance',
     'has_pubmed',
+    'has_pmc',
     'has_authors',
     'is_causal_relation',
     'not_causal_relation',
@@ -57,15 +59,16 @@ def edge_predicate(func: DictEdgePredicate) -> EdgePredicate:  # noqa: D202
     return _wrapped
 
 
-def keep_edge_permissive(*args, **kwargs) -> bool:
-    """Return true for all edges.
-
-    :param dict data: A PyBEL edge data dictionary from a :class:`pybel.BELGraph`
-    :return: Always returns :code:`True`
-    """
+def true_edge_predicate(graph: BELGraph, u: BaseEntity, v: BaseEntity, k: str) -> bool:
+    """Return true for all edges."""
     return True
 
 
+def false_edge_predicate(graph: BELGraph, u: BaseEntity, v: BaseEntity, k: str) -> bool:
+    """Return false for all edges."""
+    return False
+
+
 @edge_predicate
 def has_provenance(edge_data: EdgeData) -> bool:
     """Check if the edge has provenance information (i.e. citation and evidence)."""
@@ -75,7 +78,19 @@ def has_provenance(edge_data: EdgeData) -> bool:
 @edge_predicate
 def has_pubmed(edge_data: EdgeData) -> bool:
     """Check if the edge has a PubMed citation."""
-    return CITATION in edge_data and CITATION_TYPE_PUBMED == edge_data[CITATION][CITATION_DB]
+    return CITATION in edge_data and edge_data[CITATION][NAMESPACE].lower() in ('pubmed', 'pmid')
+
+
+@edge_predicate
+def has_pmc(edge_data: EdgeData) -> bool:
+    """Check if the edge has a PMC citation."""
+    return CITATION in edge_data and edge_data[CITATION][NAMESPACE].lower() in ('pmc', 'pmcid')
+
+
+CITATION_PREDIACATES = {
+    'pubmed': has_pubmed,
+    'pmc': has_pmc,
+}
 
 
 @edge_predicate
@@ -122,7 +137,10 @@ def _has_modifier(edge_data: EdgeData, modifier: str) -> bool:
                         :data:`pybel.constants.DEGRADATION`, or :data:`pybel.constants.TRANSLOCATION`.
     :return: Does either the subject or object have the given modifier
     """
-    return part_has_modifier(edge_data, SUBJECT, modifier) or part_has_modifier(edge_data, OBJECT, modifier)
+    return (
+        part_has_modifier(edge_data, SOURCE_MODIFIER, modifier)
+        or part_has_modifier(edge_data, TARGET_MODIFIER, modifier)
+    )
 
 
 @edge_predicate
