@@ -16,6 +16,7 @@ from typing import Iterable, Set
 from .node_predicate_builders import function_inclusion_filter_builder, namespace_inclusion_builder
 from .node_predicates import concatenate_node_predicates
 from .typing import NodePredicates
+from ..graph import BELGraph
 from ...dsl import BaseEntity
 from ...typing import Strings
 
@@ -29,7 +30,7 @@ __all__ = [
 ]
 
 
-def filter_nodes(graph, node_predicates: NodePredicates) -> Iterable[BaseEntity]:
+def filter_nodes(graph: BELGraph, node_predicates: NodePredicates) -> Iterable[BaseEntity]:
     """Apply a set of predicates to the nodes iterator of a BEL graph."""
     concatenated_predicate = concatenate_node_predicates(node_predicates=node_predicates)
     for node in graph:
@@ -37,17 +38,17 @@ def filter_nodes(graph, node_predicates: NodePredicates) -> Iterable[BaseEntity]
             yield node
 
 
-def get_nodes(graph, node_predicates: NodePredicates) -> Set[BaseEntity]:
+def get_nodes(graph: BELGraph, node_predicates: NodePredicates) -> Set[BaseEntity]:
     """Get the set of all nodes that pass the predicates."""
     return set(filter_nodes(graph, node_predicates=node_predicates))
 
 
-def count_passed_node_filter(graph, node_predicates: NodePredicates) -> int:
+def count_passed_node_filter(graph: BELGraph, node_predicates: NodePredicates) -> int:
     """Count how many nodes pass a given set of node predicates."""
     return sum(1 for _ in filter_nodes(graph, node_predicates=node_predicates))
 
 
-def summarize_node_filter(graph, node_filters: NodePredicates) -> None:
+def summarize_node_filter(graph: BELGraph, node_filters: NodePredicates) -> None:
     """Print a summary of the number of nodes passing a given set of filters.
 
     :param graph: A BEL graph
@@ -57,7 +58,7 @@ def summarize_node_filter(graph, node_filters: NodePredicates) -> None:
     print('{}/{} nodes passed'.format(passed, graph.number_of_nodes()))
 
 
-def get_nodes_by_function(graph, func: Strings) -> Set[BaseEntity]:
+def get_nodes_by_function(graph: BELGraph, func: Strings) -> Set[BaseEntity]:
     """Get all nodes with the given function(s)."""
     return get_nodes(graph, function_inclusion_filter_builder(func))
 
