@@ -4,9 +4,11 @@
 
 import logging
 from collections import defaultdict
+from typing import Mapping, Optional
 
-from .utils import cleanup
+from ..graph import BELGraph
 from ...constants import ANNOTATIONS
+from ...language import Entity
 
 __all__ = [
     'get_subgraphs_by_annotation',
@@ -15,8 +17,8 @@ __all__ = [
 logger = logging.getLogger(__name__)
 
 
-def _get_subgraphs_by_annotation_disregard_undefined(graph, annotation):
-    result = defaultdict(graph.__class__)
+def _get_subgraphs_by_annotation_disregard_undefined(graph: BELGraph, annotation: str) -> Mapping[Entity, BELGraph]:
+    result = defaultdict(graph.child)
 
     for source, target, key, data in graph.edges(keys=True, data=True):
         annotation_dict = data.get(ANNOTATIONS)
@@ -27,14 +29,18 @@ def _get_subgraphs_by_annotation_disregard_undefined(graph, annotation):
         if annotation not in annotation_dict:
             continue
 
-        for value in annotation_dict[annotation]:
-            result[value].add_edge(source, target, key=key, **data)
+        for entity in annotation_dict[annotation]:
+            result[entity].add_edge(source, target, key=key, **data)
 
     return dict(result)
 
 
-def _get_subgraphs_by_annotation_keep_undefined(graph, annotation, sentinel):
-    result = defaultdict(graph.__class__)
+def _get_subgraphs_by_annotation_keep_undefined(
+    graph: BELGraph,
+    annotation: str,
+    sentinel: Optional[str],
+) -> Mapping[Entity, BELGraph]:
+    result = defaultdict(graph.child)
 
     for source, target, key, data in graph.edges(keys=True, data=True):
         annotation_dict = data.get(ANNOTATIONS)
@@ -42,25 +48,26 @@ def _get_subgraphs_by_annotation_keep_undefined(graph, annotation, sentinel):
         if annotation_dict is None or annotation not in annotation_dict:
             result[sentinel].add_edge(source, target, key=key, **data)
         else:
-            for value in annotation_dict[annotation]:
-                result[value].add_edge(source, target, key=key, **data)
+            for entity in annotation_dict[annotation]:
+                result[entity].add_edge(source, target, key=key, **data)
 
     return dict(result)
 
 
-def get_subgraphs_by_annotation(graph, annotation, sentinel=None):
+def get_subgraphs_by_annotation(
+    graph: BELGraph,
+    annotation: str,
+    sentinel: Optional[str] = None,
+) -> Mapping[Entity, BELGraph]:
     """Stratify the given graph into sub-graphs based on the values for edges' annotations.
 
-    :param pybel.BELGraph graph: A BEL graph
-    :param str annotation: The annotation to group by
-    :param Optional[str] sentinel: The value to stick unannotated edges into. If none, does not keep undefined.
-    :rtype: dict[str,pybel.BELGraph]
+    :param graph: A BEL graph
+    :param annotation: The annotation to group by
+    :param sentinel: The value to stick unannotated edges into. If none, does not keep undefined.
     """
     if sentinel is not None:
         subgraphs = _get_subgraphs_by_annotation_keep_undefined(graph, annotation, sentinel)
     else:
         subgraphs = _get_subgraphs_by_annotation_disregard_undefined(graph, annotation)
 
-    cleanup(graph, subgraphs)
-
     return subgraphs
