@@ -2,8 +2,6 @@
 
 """Utilities for :mod:`pybel.struct`."""
 
-import networkx as nx
-
 from ..constants import (
     GRAPH_ANNOTATION_LIST, GRAPH_ANNOTATION_PATTERN, GRAPH_ANNOTATION_URL, GRAPH_NAMESPACE_PATTERN,
     GRAPH_NAMESPACE_URL,
@@ -11,7 +9,6 @@ from ..constants import (
 
 __all__ = [
     'update_metadata',
-    'update_node_helper',
 ]
 
 
@@ -31,14 +28,3 @@ def update_metadata(source, target) -> None:
             target.annotation_list[keyword] = values
         else:
             target.annotation_list[keyword].update(values)
-
-
-def update_node_helper(source: nx.Graph, target: nx.Graph) -> None:
-    """Update the nodes' data dictionaries in the target graph from the source graph.
-
-    :param source: The universe of all knowledge
-    :param target: The target BEL graph
-    """
-    for node in target:
-        if node in source:
-            target.nodes[node].update(source.nodes[node])
