@@ -10,24 +10,26 @@ from json import dumps
 from pybel import BELGraph
 from pybel.canonicalize import edge_to_bel
 from pybel.constants import (
-    ANNOTATIONS, ASSOCIATION, CITATION, CITATION_DB, CITATION_IDENTIFIER, CITATION_TYPE_PUBMED, DECREASES,
-    DIRECTLY_DECREASES, EVIDENCE, INCREASES, METADATA_AUTHORS, METADATA_DESCRIPTION, METADATA_LICENSES, METADATA_NAME,
-    METADATA_VERSION, PART_OF, RELATION,
+    ANNOTATIONS, ASSOCIATION, CITATION, CITATION_TYPE_PUBMED, DECREASES, DIRECTLY_DECREASES, EVIDENCE, IDENTIFIER,
+    INCREASES, LINE, METADATA_AUTHORS, METADATA_DESCRIPTION, METADATA_LICENSES, METADATA_NAME, METADATA_VERSION,
+    NAMESPACE, PART_OF, RELATION,
 )
 from pybel.dsl import BaseEntity, ComplexAbundance, Pathology, Protein
 from pybel.dsl.namespaces import hgnc
-from pybel.parser.exc import (
-    BELParserWarning, BELSyntaxError, IllegalAnnotationValueWarning, InvalidCitationLengthException,
+from pybel.exceptions import (
+    BELParserWarning, BELSyntaxError, CitationTooShortException, IllegalAnnotationValueWarning,
+    InvalidCitationLengthException,
     InvalidCitationType, InvalidFunctionSemantic, InvalidPubMedIdentifierWarning, MalformedTranslocationWarning,
     MissingAnnotationKeyWarning, MissingAnnotationRegexWarning, MissingCitationException, MissingMetadataException,
     MissingNamespaceNameWarning, MissingNamespaceRegexWarning, MissingSupportWarning, NakedNameWarning,
     NestedRelationWarning, PlaceholderAminoAcidWarning, UndefinedAnnotationWarning, UndefinedNamespaceWarning,
     VersionFormatWarning,
 )
+from pybel.language import Entity, citation_dict
 from pybel.parser.parse_bel import BELParser
 from pybel.parser.parse_control import ControlParser
 from pybel.testing.constants import test_bel_thorough
-from pybel.utils import citation_dict, subdict_matches
+from pybel.utils import subdict_matches
 from tests.constant_helper import (
     BEL_THOROUGH_EDGES, BEL_THOROUGH_NODES, citation_1, evidence_1, expected_test_simple_metadata,
     expected_test_thorough_metadata,
@@ -38,11 +40,11 @@ logger = logging.getLogger(__name__)
 OPENBEL_DOMAIN = 'http://resources.openbel.org'
 OPENBEL_ANNOTATION_RESOURCES = OPENBEL_DOMAIN + '/belframework/20150611/annotation/'
 
-test_citation_dict = citation_dict(db=CITATION_TYPE_PUBMED, db_id='1235813')
+test_citation_dict = citation_dict(namespace=CITATION_TYPE_PUBMED, identifier='1235813')
 
-SET_CITATION_TEST = 'SET Citation = {{"{db}", "{db_id}"}}'.format(**test_citation_dict)
+SET_CITATION_TEST = f'SET Citation = {{"{test_citation_dict.namespace}", "{test_citation_dict.identifier}"}}'
 test_evidence_text = 'I read it on Twitter'
-test_set_evidence = 'SET Evidence = "{}"'.format(test_evidence_text)
+test_set_evidence = f'SET Evidence = "{test_evidence_text}"'
 
 HGNC_KEYWORD = 'HGNC'
 MESH_DISEASES_KEYWORD = 'MeSHDisease'
@@ -56,8 +58,8 @@ casp8 = hgnc(name='CASP8')
 
 def update_provenance(control_parser: ControlParser) -> None:
     """Put a default evidence and citation in a BEL parser."""
-    control_parser.citation_db = test_citation_dict[CITATION_DB]
-    control_parser.citation_db_id = test_citation_dict[CITATION_IDENTIFIER]
+    control_parser.citation_db = test_citation_dict.namespace
+    control_parser.citation_db_id = test_citation_dict.identifier
     control_parser.evidence = test_evidence_text
 
 
@@ -109,14 +111,20 @@ def any_subdict_matches(dict_of_dicts, query_dict) -> bool:
     )
 
 
+def _remove_line(d):
+    return {k: v for k, v in d.items() if k != LINE}
+
+
 def assert_has_edge(
     self: unittest.TestCase,
     u: BaseEntity,
     v: BaseEntity,
     graph: BELGraph,
+    *,
+    only: bool = False,
     permissive: bool = True,
     use_identifiers: bool = False,
-    **kwargs
+    **expected_edge_data
 ):
     """A helper function for checking if an edge with the given properties is contained within a graph."""
     self.assertIsInstance(u, BaseEntity)
@@ -130,21 +138,32 @@ def assert_has_edge(
         ))
     )
 
-    if not kwargs:
+    if not expected_edge_data:
         return
 
-    if permissive:
-        matches = any_subdict_matches(graph[u][v], kwargs)
-    else:
-        matches = any_dict_matches(graph[u][v], kwargs)
+    if ANNOTATIONS in expected_edge_data:
+        expected_edge_data[ANNOTATIONS] = graph._clean_annotations(expected_edge_data[ANNOTATIONS])
 
-    msg = 'No edge ({}, {}) with correct properties. expected:\n {}\nbut got:\n{}'.format(
-        u,
-        v,
-        dumps(kwargs, indent=2, sort_keys=True),
-        str(graph[u][v])
-    )
-    self.assertTrue(matches, msg=msg)
+    if only:
+        _key, actual_edge_data = list(graph[u][v].items())[0]
+        self.assertEqual(_remove_line(expected_edge_data), _remove_line(actual_edge_data), msg='Only entry not equal')
+    else:
+        actual_dicts = {
+            k: _remove_line(v)
+            for k, v in graph[u][v].items()
+        }
+        if permissive:
+            matches = any_subdict_matches(actual_dicts, _remove_line(expected_edge_data))
+        else:
+            matches = any_dict_matches(actual_dicts, _remove_line(expected_edge_data))
+
+        msg = 'No edge ({}, {}) with correct properties. expected:\n {}\nbut got:\n{}'.format(
+            u,
+            v,
+            dumps(expected_edge_data, indent=2, sort_keys=True),
+            dumps(actual_dicts, indent=2, sort_keys=True),
+        )
+        self.assertTrue(matches, msg=msg)
 
 
 class TestGraphMixin(unittest.TestCase):
@@ -154,9 +173,9 @@ class TestGraphMixin(unittest.TestCase):
         """Help assert node membership."""
         assert_has_node(self, n, g, **kwargs)
 
-    def assert_has_edge(self, g: BELGraph, u: BaseEntity, v: BaseEntity, **kwargs):
+    def assert_has_edge(self, g: BELGraph, u: BaseEntity, v: BaseEntity, only=False, permissive=True, **kwargs):
         """Help assert edge membership."""
-        assert_has_edge(self, u, v, g, **kwargs)
+        assert_has_edge(self, u, v, g, only=only, permissive=permissive, **kwargs)
 
 
 class TestTokenParserBase(unittest.TestCase):
@@ -165,9 +184,8 @@ class TestTokenParserBase(unittest.TestCase):
     @classmethod
     def setUpClass(cls):
         """Build a BEL graph and BEL parser that persist through the class."""
-        cls.graph = BELGraph()
         cls.parser = BELParser(
-            cls.graph,
+            BELGraph(),  # gets overwritten in each test
             autostreamline=False,
             disallow_unqualified_translocations=True,
             namespace_to_pattern={
@@ -183,20 +201,25 @@ class TestTokenParserBase(unittest.TestCase):
                 'MESH': re.compile(r'.*'),
                 'MGI': re.compile(r'.*'),
                 'dbSNP': re.compile(r'.*'),
-            }
+            },
         )
 
+    @property
+    def graph(self):
+        return self.parser.graph
+
     def setUp(self):
         """Clear the parser at the beginning of each test."""
         self.parser.clear()
+        self.parser.graph = BELGraph()  # because all the good stuff in the graph is cleared
 
     def assert_has_node(self, member: BaseEntity, **kwargs):
         """Assert that this test case's graph has the given node."""
         assert_has_node(self, member, self.graph, **kwargs)
 
-    def assert_has_edge(self, u: BaseEntity, v: BaseEntity, **kwargs):
+    def assert_has_edge(self, u: BaseEntity, v: BaseEntity, only: bool = False, **kwargs):
         """Assert that this test case's graph has the given edge."""
-        assert_has_edge(self, u, v, self.graph, **kwargs)
+        assert_has_edge(self, u, v, self.graph, only=only, **kwargs)
 
     def add_default_provenance(self):
         """Add a default citation and evidence to the parser."""
@@ -247,66 +270,59 @@ class BelReconstitutionMixin(TestGraphMixin):
         self.assertIn(fadd, graph)
         self.assertIn(casp8, graph)
 
-        bel_simple_citation_1 = {
-            CITATION_IDENTIFIER: "123455",
-            CITATION_DB: CITATION_TYPE_PUBMED,
-        }
-
-        bel_simple_citation_2 = {
-            CITATION_IDENTIFIER: "123456",
-            CITATION_DB: CITATION_TYPE_PUBMED,
-        }
+        bel_simple_citation_1 = citation_dict(namespace=CITATION_TYPE_PUBMED, identifier="123455")
+        bel_simple_citation_2 = citation_dict(namespace=CITATION_TYPE_PUBMED, identifier="123456")
 
         evidence_1_extra = "Evidence 1 w extra notes"
         evidence_2 = 'Evidence 2'
         evidence_3 = 'Evidence 3'
 
-        assert_has_edge(self, akt1, egfr, graph, **{
+        assert_has_edge(self, akt1, egfr, graph, only=True, **{
             RELATION: INCREASES,
             CITATION: bel_simple_citation_1,
             EVIDENCE: evidence_1_extra,
             ANNOTATIONS: {
-                'Species': {'9606': True}
+                'Species': [Entity(namespace='Species', identifier='9606')],
             }
         })
-        assert_has_edge(self, egfr, fadd, graph, **{
+        assert_has_edge(self, egfr, fadd, graph, only=True, **{
             RELATION: DECREASES,
             ANNOTATIONS: {
-                'Species': {'9606': True},
-                'CellLine': {'10B9 cell': True}
+                'Species': [Entity(namespace='Species', identifier='9606')],
+                'CellLine': [Entity(namespace='CellLine', identifier='10B9 cell')],
             },
             CITATION: bel_simple_citation_1,
             EVIDENCE: evidence_2
         })
-        assert_has_edge(self, egfr, casp8, graph, **{
+        assert_has_edge(self, egfr, casp8, graph, only=True, **{
             RELATION: DIRECTLY_DECREASES,
             ANNOTATIONS: {
-                'Species': {'9606': True},
-                'CellLine': {'10B9 cell': True}
+                'Species': [Entity(namespace='Species', identifier='9606')],
+                'CellLine': [Entity(namespace='CellLine', identifier='10B9 cell')],
             },
             CITATION: bel_simple_citation_1,
             EVIDENCE: evidence_2,
         })
-        assert_has_edge(self, fadd, casp8, graph, **{
+        assert_has_edge(self, fadd, casp8, graph, only=True, **{
             RELATION: INCREASES,
             ANNOTATIONS: {
-                'Species': {'10116': True}
+                'Species': [Entity(namespace='Species', identifier='10116')],
             },
             CITATION: bel_simple_citation_2,
             EVIDENCE: evidence_3,
         })
-        assert_has_edge(self, akt1, casp8, graph, **{
+        assert_has_edge(self, akt1, casp8, graph, only=True, **{
             RELATION: ASSOCIATION,
             ANNOTATIONS: {
-                'Species': {'10116': True}
+                'Species': [Entity(namespace='Species', identifier='10116')],
             },
             CITATION: bel_simple_citation_2,
             EVIDENCE: evidence_3,
         })
-        assert_has_edge(self, casp8, akt1, graph, **{
+        assert_has_edge(self, casp8, akt1, graph, only=True, **{
             RELATION: ASSOCIATION,
             ANNOTATIONS: {
-                'Species': {'10116': True}
+                'Species': [Entity(namespace='Species', identifier='10116')],
             },
             CITATION: bel_simple_citation_2,
             EVIDENCE: evidence_3,
@@ -358,7 +374,7 @@ class BelReconstitutionMixin(TestGraphMixin):
         for node in graph:
             self.assertIsInstance(node, BaseEntity)
 
-        self.assertEqual(set(BEL_THOROUGH_NODES), set(graph), msg='Nodes not equal')
+        self.assertEqual(sorted(BEL_THOROUGH_NODES, key=str), sorted(graph, key=str), msg='Nodes not equal')
 
         # FIXME
         # self.assertEqual(set((u, v) for u, v, _ in e), set(g.edges()))
@@ -395,7 +411,7 @@ class BelReconstitutionMixin(TestGraphMixin):
                 (3, VersionFormatWarning),
                 (26, MissingAnnotationKeyWarning),
                 (29, MissingAnnotationKeyWarning),
-                (34, InvalidCitationLengthException),
+                (34, CitationTooShortException),
                 (37, InvalidCitationType),
                 (40, InvalidPubMedIdentifierWarning),
                 (43, MissingCitationException),
@@ -421,6 +437,12 @@ class BelReconstitutionMixin(TestGraphMixin):
             for warning_tuple in graph.warnings:
                 self.assertEqual(3, len(warning_tuple), msg='Warning tuple is wrong size: {}'.format(warning_tuple))
 
+            _sliced_warnings = [
+                (w.line_number, w.__class__)
+                for _, w, _ in graph.warnings
+            ]
+            self.assertEqual(expected_warnings, _sliced_warnings, msg='wrong warnings')
+
             for (el, ew), (_, exc, _) in zip(expected_warnings, graph.warnings):
                 self.assertIsInstance(exc, BELParserWarning)
                 self.assertIsInstance(exc.line, str)
@@ -440,7 +462,7 @@ class BelReconstitutionMixin(TestGraphMixin):
         self.assertEqual(2, graph.number_of_nodes(), msg='Wrong number of nodes retrieved from slushy.bel')
         self.assertEqual(1, graph.number_of_edges(), msg='Wrong nunber of edges retrieved from slushy.bel')
 
-        assert_has_edge(self, akt1, egfr, graph, **{
+        assert_has_edge(self, akt1, egfr, graph, only=True, **{
             RELATION: INCREASES,
             CITATION: citation_1,
             EVIDENCE: evidence_1,
@@ -464,5 +486,5 @@ class BelReconstitutionMixin(TestGraphMixin):
         self.assertIn(adgrb_complex, graph)
         self.assertIn(achlorhydria, graph)
 
-        assert_has_edge(self, adgrb1, adgrb_complex, graph, relation=PART_OF)
-        assert_has_edge(self, adgrb2, adgrb_complex, graph, relation=PART_OF)
+        assert_has_edge(self, adgrb1, adgrb_complex, graph, only=True, relation=PART_OF)
+        assert_has_edge(self, adgrb2, adgrb_complex, graph, only=True, relation=PART_OF)
