@@ -10,21 +10,22 @@ from pyparsing import ParseException
 from pybel import BELGraph
 from pybel.canonicalize import edge_to_bel
 from pybel.constants import (
-    ABUNDANCE, ACTIVITY, ANNOTATIONS, BEL_DEFAULT_NAMESPACE, BIOPROCESS, CAUSES_NO_CHANGE, CITATION, COMPLEX,
-    COMPOSITE, CONCEPT, CORRELATION, DECREASES, DIRECTLY_DECREASES, DIRECTLY_INCREASES, EFFECT, EQUIVALENT_TO, EVIDENCE,
-    FROM_LOC, FUNCTION, GENE, GMOD, HAS_PRODUCT, HAS_REACTANT, HAS_VARIANT, HGVS, INCREASES, IS_A, KIND, LOCATION,
-    MEMBERS, MODIFIER, NAME, NAMESPACE, NEGATIVE_CORRELATION, NO_CORRELATION, OBJECT, ORTHOLOGOUS, PART_OF, PATHOLOGY,
-    POSITIVE_CORRELATION, PRODUCTS, PROTEIN, RATE_LIMITING_STEP_OF, REACTANTS, REACTION, REGULATES, RELATION, RNA,
-    SUBJECT, SUBPROCESS_OF, TARGET, TO_LOC, TRANSCRIBED_TO, TRANSLATED_TO, TRANSLOCATION, VARIANTS,
+    ABUNDANCE, ACTIVITY, ANNOTATIONS, BIOPROCESS, CAUSES_NO_CHANGE, CITATION, COMPLEX, COMPOSITE, CONCEPT, CORRELATION,
+    DECREASES, DIRECTLY_DECREASES, DIRECTLY_INCREASES, EFFECT, EQUIVALENT_TO, EVIDENCE, FROM_LOC, FUNCTION, GENE, GMOD,
+    GRAPH_ANNOTATION_LIST, HAS_PRODUCT, HAS_REACTANT, HAS_VARIANT, HGVS, IDENTIFIER, INCREASES, IS_A, KIND, LOCATION,
+    MEMBERS, MODIFIER, NAME,
+    NAMESPACE, NEGATIVE_CORRELATION, NO_CORRELATION, ORTHOLOGOUS, PART_OF, PATHOLOGY, POSITIVE_CORRELATION, PRODUCTS,
+    PROTEIN, RATE_LIMITING_STEP_OF, REACTANTS, REACTION, REGULATES, RELATION, RNA, SOURCE, SOURCE_MODIFIER,
+    SUBPROCESS_OF, TARGET, TARGET_MODIFIER, TO_LOC, TRANSCRIBED_TO, TRANSLATED_TO, TRANSLOCATION, VARIANTS,
 )
 from pybel.dsl import (
     ComplexAbundance, Pathology, Protein, Rna, abundance, activity, bioprocess, complex_abundance, composite_abundance,
     gene, gmod, hgvs, named_complex_abundance, pmod, protein, reaction, rna,
 )
 from pybel.dsl.namespaces import hgnc
-from pybel.language import Entity
+from pybel.exceptions import MissingNamespaceNameWarning, NestedRelationWarning, UndefinedNamespaceWarning
+from pybel.language import Entity, activity_mapping
 from pybel.parser import BELParser
-from pybel.parser.exc import MissingNamespaceNameWarning, NestedRelationWarning, UndefinedNamespaceWarning
 from tests.constants import TestTokenParserBase, test_citation_dict, test_evidence_text
 
 logger = logging.getLogger(__name__)
@@ -136,10 +137,15 @@ class TestRelations(TestTokenParserBase):
 
     def test_increases_methylation(self):
         """Test a causal statement with a gene modification."""
-        statement = 'a(CHEBI:"lead atom") -> g(HGNC:APP, gmod(Me))'
+        for gmod in ['Me', 'go:0006306 ! "DNA methylation"']:
+            with self.subTest(gmod=gmod):
+                self._help_test_increases_methylation(gmod)
+
+    def _help_test_increases_methylation(self, x):
+        statement = f'a(CHEBI:"lead atom") -> g(HGNC:APP, gmod({x}))'
         result = self.parser.relation.parseString(statement)
         expected_dict = {
-            OBJECT: {
+            TARGET: {
                 FUNCTION: GENE,
                 CONCEPT: {
                     NAMESPACE: 'HGNC',
@@ -149,14 +155,15 @@ class TestRelations(TestTokenParserBase):
                     {
                         KIND: GMOD,
                         CONCEPT: {
-                            NAMESPACE: BEL_DEFAULT_NAMESPACE,
-                            NAME: 'Me',
+                            NAMESPACE: 'go',
+                            IDENTIFIER: '0006306',
+                            NAME: 'DNA methylation',
                         },
                     },
                 ],
             },
             RELATION: INCREASES,
-            SUBJECT: {
+            SOURCE: {
                 FUNCTION: ABUNDANCE,
                 CONCEPT: {
                     NAMESPACE: 'CHEBI',
@@ -180,7 +187,7 @@ class TestRelations(TestTokenParserBase):
         result = self.parser.relation.parseString(statement)
 
         expected_dict = {
-            SUBJECT: {
+            SOURCE: {
                 FUNCTION: ABUNDANCE,
                 CONCEPT: {
                     NAMESPACE: 'CHEBI',
@@ -188,13 +195,11 @@ class TestRelations(TestTokenParserBase):
                 },
             },
             RELATION: DIRECTLY_INCREASES,
-            OBJECT: {
-                TARGET: {
-                    FUNCTION: ABUNDANCE,
-                    CONCEPT: {
-                        NAMESPACE: 'CHEBI',
-                        NAME: 'calcium(2+)',
-                    },
+            TARGET: {
+                FUNCTION: ABUNDANCE,
+                CONCEPT: {
+                    NAMESPACE: 'CHEBI',
+                    NAME: 'calcium(2+)',
                 },
                 MODIFIER: TRANSLOCATION,
                 EFFECT: {
@@ -213,7 +218,7 @@ class TestRelations(TestTokenParserBase):
 
         expected_annotations = {
             RELATION: DIRECTLY_INCREASES,
-            OBJECT: {
+            TARGET_MODIFIER: {
                 MODIFIER: TRANSLOCATION,
                 EFFECT: {
                     FROM_LOC: {NAMESPACE: 'MESH', NAME: 'Cell Membrane'},
@@ -233,23 +238,18 @@ class TestRelations(TestTokenParserBase):
         result = self.parser.relation.parseString(statement)
 
         expected_dict = {
-            SUBJECT: {
+            SOURCE: {
                 MODIFIER: ACTIVITY,
-                TARGET: {
-                    FUNCTION: PROTEIN,
-                    CONCEPT: {
-                        NAMESPACE: 'FPLX',
-                        NAME: 'CAPN',
-                    },
-                    LOCATION: {NAMESPACE: 'GO', NAME: 'intracellular'}
-                },
-                EFFECT: {
-                    NAME: 'pep',
-                    NAMESPACE: BEL_DEFAULT_NAMESPACE
+                FUNCTION: PROTEIN,
+                CONCEPT: {
+                    NAMESPACE: 'FPLX',
+                    NAME: 'CAPN',
                 },
+                LOCATION: {NAMESPACE: 'GO', NAME: 'intracellular'},
+                EFFECT: activity_mapping['pep'],
             },
             RELATION: DECREASES,
-            OBJECT: {
+            TARGET: {
                 FUNCTION: REACTION,
                 REACTANTS: [
                     {
@@ -290,12 +290,9 @@ class TestRelations(TestTokenParserBase):
 
         expected_edge_attributes = {
             RELATION: DECREASES,
-            SUBJECT: {
+            SOURCE_MODIFIER: {
                 MODIFIER: ACTIVITY,
-                EFFECT: {
-                    NAME: 'pep',
-                    NAMESPACE: BEL_DEFAULT_NAMESPACE,
-                },
+                EFFECT: activity_mapping['pep'],
                 LOCATION: {
                     NAMESPACE: 'GO',
                     NAME: 'intracellular',
@@ -303,8 +300,10 @@ class TestRelations(TestTokenParserBase):
             }
         }
 
-        self.assertEqual(expected_edge_attributes[SUBJECT],
-                         activity(name='pep', location=Entity(name='intracellular', namespace='GO')))
+        self.assertEqual(
+            expected_edge_attributes[SOURCE_MODIFIER],
+            activity(name='pep', location=Entity(name='intracellular', namespace='GO')),
+        )
 
         self.assert_has_edge(sub, obj, **expected_edge_attributes)
 
@@ -316,7 +315,7 @@ class TestRelations(TestTokenParserBase):
         result = self.parser.relation.parseString(statement)
 
         expected_dict = {
-            SUBJECT: {
+            SOURCE: {
                 FUNCTION: PROTEIN,
                 CONCEPT: {
                     NAMESPACE: 'HGNC',
@@ -325,7 +324,7 @@ class TestRelations(TestTokenParserBase):
                 LOCATION: {NAMESPACE: 'GO', NAME: 'intracellular'}
             },
             RELATION: DIRECTLY_DECREASES,
-            OBJECT: {
+            TARGET: {
                 FUNCTION: ABUNDANCE,
                 CONCEPT: {
                     NAMESPACE: 'CHEBI',
@@ -342,7 +341,7 @@ class TestRelations(TestTokenParserBase):
         self.assert_has_node(obj)
 
         expected_attrs = {
-            SUBJECT: {
+            SOURCE_MODIFIER: {
                 LOCATION: {NAMESPACE: 'GO', NAME: 'intracellular'}
             },
             RELATION: DIRECTLY_DECREASES,
@@ -355,17 +354,21 @@ class TestRelations(TestTokenParserBase):
         Tests simple triple"""
         statement = 'g(HGNC:CAT, location(GO:intracellular)) directlyDecreases abundance(CHEBI:"hydrogen peroxide")'
 
-        annotations = {
+        self.graph.annotation_list.update({
+            'ListAnnotation': set('abef'),
+            'ScalarAnnotation': set('cghi'),
+        })
+        annotations = self.parser.graph._clean_annotations({
             'ListAnnotation': {'a', 'b'},
-            'ScalarAnnotation': {'c'}
-        }
+            'ScalarAnnotation': {'c'},
+        })
 
         self.parser.control_parser.annotations.update(annotations)
 
         result = self.parser.relation.parseString(statement)
 
         expected_dict = {
-            SUBJECT: {
+            SOURCE: {
                 FUNCTION: GENE,
                 CONCEPT: {
                     NAMESPACE: 'HGNC',
@@ -377,7 +380,7 @@ class TestRelations(TestTokenParserBase):
                 }
             },
             RELATION: DIRECTLY_DECREASES,
-            OBJECT: {
+            TARGET: {
                 FUNCTION: ABUNDANCE,
                 CONCEPT: {
                     NAMESPACE: 'CHEBI',
@@ -394,7 +397,7 @@ class TestRelations(TestTokenParserBase):
         self.assert_has_node(obj)
 
         expected_attrs = {
-            SUBJECT: {
+            SOURCE_MODIFIER: {
                 LOCATION: {
                     NAMESPACE: 'GO',
                     NAME: 'intracellular'
@@ -404,11 +407,16 @@ class TestRelations(TestTokenParserBase):
             CITATION: test_citation_dict,
             EVIDENCE: test_evidence_text,
             ANNOTATIONS: {
-                'ListAnnotation': {'a': True, 'b': True},
-                'ScalarAnnotation': {'c': True},
-            }
+                'ListAnnotation': [
+                    Entity(namespace='ListAnnotation', identifier='a'),
+                    Entity(namespace='ListAnnotation', identifier='b'),
+                ],
+                'ScalarAnnotation': [
+                    Entity(namespace='ScalarAnnotation', identifier='c'),
+                ],
+            },
         }
-        self.assert_has_edge(sub, obj, **expected_attrs)
+        self.assert_has_edge(sub, obj, only=True, **expected_attrs)
 
     def test_rateLimitingStepOf_subjectActivity(self):
         """3.1.5 http://openbel.org/language/web/version_2.0/bel_specification_version_2.0.html#_ratelimitingstepof"""
@@ -416,22 +424,17 @@ class TestRelations(TestTokenParserBase):
         result = self.parser.relation.parseString(statement)
 
         expected_dict = {
-            SUBJECT: {
+            SOURCE: {
                 MODIFIER: ACTIVITY,
-                TARGET: {
-                    FUNCTION: PROTEIN,
-                    CONCEPT: {
-                        NAMESPACE: 'HGNC',
-                        NAME: 'HMGCR',
-                    },
-                },
-                EFFECT: {
-                    NAME: 'cat',
-                    NAMESPACE: BEL_DEFAULT_NAMESPACE
+                FUNCTION: PROTEIN,
+                CONCEPT: {
+                    NAMESPACE: 'HGNC',
+                    NAME: 'HMGCR',
                 },
+                EFFECT: activity_mapping['cat'],
             },
             RELATION: RATE_LIMITING_STEP_OF,
-            OBJECT: {
+            TARGET: {
                 FUNCTION: BIOPROCESS,
                 CONCEPT: {
                     NAMESPACE: 'GO',
@@ -458,7 +461,7 @@ class TestRelations(TestTokenParserBase):
         result = self.parser.relation.parseString(statement)
 
         expected_dict = {
-            SUBJECT: {
+            SOURCE: {
                 FUNCTION: GENE,
                 CONCEPT: {
                     NAMESPACE: 'HGNC',
@@ -472,7 +475,7 @@ class TestRelations(TestTokenParserBase):
                 ],
             },
             RELATION: CAUSES_NO_CHANGE,
-            OBJECT: {
+            TARGET: {
                 FUNCTION: PATHOLOGY,
                 CONCEPT: {
                     NAMESPACE: 'MESH',
@@ -500,39 +503,29 @@ class TestRelations(TestTokenParserBase):
         result = self.parser.relation.parseString(statement)
 
         expected_dict = {
-            SUBJECT: {
+            SOURCE: {
                 MODIFIER: ACTIVITY,
-                EFFECT: {
-                    NAME: 'pep',
-                    NAMESPACE: BEL_DEFAULT_NAMESPACE
-                },
-                TARGET: {
-                    FUNCTION: COMPLEX,
-                    MEMBERS: [
-                        {
-                            FUNCTION: PROTEIN,
-                            CONCEPT: {NAMESPACE: 'HGNC', NAME: 'F3'}
-                        },
-                        {
-                            FUNCTION: PROTEIN,
-                            CONCEPT: {NAMESPACE: 'HGNC', NAME: 'F7'}
-                        },
-                    ]
-                }
+                EFFECT: activity_mapping['pep'],
+                FUNCTION: COMPLEX,
+                MEMBERS: [
+                    {
+                        FUNCTION: PROTEIN,
+                        CONCEPT: {NAMESPACE: 'HGNC', NAME: 'F3'}
+                    },
+                    {
+                        FUNCTION: PROTEIN,
+                        CONCEPT: {NAMESPACE: 'HGNC', NAME: 'F7'}
+                    },
+                ],
             },
             RELATION: REGULATES,
-            OBJECT: {
+            TARGET: {
                 MODIFIER: ACTIVITY,
-                EFFECT: {
-                    NAME: 'pep',
-                    NAMESPACE: BEL_DEFAULT_NAMESPACE
-                },
-                TARGET: {
-                    FUNCTION: PROTEIN,
-                    CONCEPT: {
-                        NAMESPACE: 'HGNC',
-                        NAME: 'F9',
-                    },
+                EFFECT: activity_mapping['pep'],
+                FUNCTION: PROTEIN,
+                CONCEPT: {
+                    NAMESPACE: 'HGNC',
+                    NAME: 'F9',
                 },
             },
         }
@@ -581,26 +574,26 @@ class TestRelations(TestTokenParserBase):
         """
         3.2.1 http://openbel.org/language/web/version_2.0/bel_specification_version_2.0.html#XnegCor
         Test phosphoralation tag"""
-        statement = 'kin(p(FPLX:GSK3)) neg p(HGNC:MAPT,pmod(P))'
+        for pmod in ['P', 'Ph', 'go:0006468 ! "protein phosphorylation"']:
+            with self.subTest(pmod=pmod):
+                self._help_test_negative_correlation_with_object_variant(pmod)
+
+    def _help_test_negative_correlation_with_object_variant(self, x):
+        statement = f'kin(p(FPLX:GSK3)) neg p(HGNC:MAPT,pmod({x}))'
         result = self.parser.relation.parseString(statement)
 
         expected_dict = {
-            SUBJECT: {
+            SOURCE: {
                 MODIFIER: ACTIVITY,
-                EFFECT: {
-                    NAME: 'kin',
-                    NAMESPACE: BEL_DEFAULT_NAMESPACE
-                },
-                TARGET: {
-                    FUNCTION: PROTEIN,
-                    CONCEPT: {
-                        NAMESPACE: 'FPLX',
-                        NAME: 'GSK3',
-                    },
+                EFFECT: activity_mapping['kin'],
+                FUNCTION: PROTEIN,
+                CONCEPT: {
+                    NAMESPACE: 'FPLX',
+                    NAME: 'GSK3',
                 },
             },
             RELATION: NEGATIVE_CORRELATION,
-            OBJECT: {
+            TARGET: {
                 FUNCTION: PROTEIN,
                 CONCEPT: {
                     NAMESPACE: 'HGNC',
@@ -628,7 +621,7 @@ class TestRelations(TestTokenParserBase):
         result = self.parser.relation.parseString(statement)
 
         expected_dict = {
-            SUBJECT: {
+            SOURCE: {
                 FUNCTION: PROTEIN,
                 CONCEPT: {
                     NAMESPACE: 'HGNC',
@@ -637,19 +630,14 @@ class TestRelations(TestTokenParserBase):
                 VARIANTS: [pmod('Ph', position=9, code='Ser')]
             },
             RELATION: POSITIVE_CORRELATION,
-            OBJECT: {
+            TARGET: {
                 MODIFIER: ACTIVITY,
-                TARGET: {
-                    FUNCTION: PROTEIN,
-                    CONCEPT: {
-                        NAMESPACE: 'HGNC',
-                        NAME: 'GSK3B',
-                    },
+                FUNCTION: PROTEIN,
+                CONCEPT: {
+                    NAMESPACE: 'HGNC',
+                    NAME: 'GSK3B',
                 },
-                EFFECT: {
-                    NAME: 'kin',
-                    NAMESPACE: BEL_DEFAULT_NAMESPACE
-                }
+                EFFECT: activity_mapping['kin'],
             },
         }
         self.assertEqual(expected_dict, result.asDict())
@@ -712,7 +700,7 @@ class TestRelations(TestTokenParserBase):
 
         # [[RNA, ['HGNC', 'AKT1']], TRANSLATED_TO, [PROTEIN, ['HGNC', 'AKT1']]]
         expected_result = {
-            SUBJECT: {
+            SOURCE: {
                 FUNCTION: RNA,
                 CONCEPT: {
                     NAMESPACE: 'HGNC',
@@ -724,7 +712,7 @@ class TestRelations(TestTokenParserBase):
                 }
             },
             RELATION: TRANSLATED_TO,
-            OBJECT: {
+            TARGET: {
                 FUNCTION: PROTEIN,
                 CONCEPT: {
                     NAMESPACE: 'HGNC',
@@ -845,7 +833,7 @@ class TestRelations(TestTokenParserBase):
         result = self.parser.relation.parseString(statement)
 
         expected_result = {
-            SUBJECT: {
+            SOURCE: {
                 FUNCTION: GENE,
                 CONCEPT: {
                     NAMESPACE: 'dbSNP',
@@ -853,7 +841,7 @@ class TestRelations(TestTokenParserBase):
                 },
             },
             RELATION: EQUIVALENT_TO,
-            OBJECT: {
+            TARGET: {
                 FUNCTION: GENE,
                 CONCEPT: {
                     NAMESPACE: 'HGNC',
@@ -966,7 +954,7 @@ class TestRelations(TestTokenParserBase):
         self.assert_has_node(expected_child)
 
         self.assertEqual('g(HGNC:AKT1)', self.graph.node_to_bel(expected_parent))
-        self.assertEqual('g(HGNC:AKT1, gmod(Me))', self.graph.node_to_bel(expected_child))
+        self.assertEqual('g(HGNC:AKT1, gmod(go:0006306 ! "DNA methylation"))', self.graph.node_to_bel(expected_child))
 
         self.assert_has_edge(expected_parent, expected_child, **{RELATION: HAS_VARIANT})
 
