@@ -6,10 +6,10 @@ import unittest
 
 from pybel import BELGraph
 from pybel.constants import (
-    ACTIVITY, ANNOTATIONS, ASSOCIATION, CAUSES_NO_CHANGE, CITATION, CITATION_AUTHORS, CITATION_DB, CITATION_IDENTIFIER,
-    CITATION_TYPE_ONLINE, CITATION_TYPE_PUBMED, DECREASES, DEGRADATION, DIRECTLY_DECREASES, DIRECTLY_INCREASES,
-    EVIDENCE, GMOD, INCREASES, LOCATION, MODIFIER, OBJECT, POLAR_RELATIONS, POSITIVE_CORRELATION, RELATION, SUBJECT,
-    TRANSLOCATION,
+    ACTIVITY, ANNOTATIONS, ASSOCIATION, CAUSES_NO_CHANGE, CITATION, CITATION_AUTHORS, CITATION_TYPE_PUBMED,
+    CITATION_TYPE_URL, DECREASES, DEGRADATION, DIRECTLY_DECREASES, DIRECTLY_INCREASES, EVIDENCE, GMOD, IDENTIFIER,
+    INCREASES, LOCATION, MODIFIER, NAMESPACE, POLAR_RELATIONS, POSITIVE_CORRELATION, RELATION, SOURCE_MODIFIER,
+    TARGET_MODIFIER, TRANSLOCATION,
 )
 from pybel.dsl import (
     abundance, activity, degradation, fragment, gene, gmod, hgvs, pmod, protein, secretion, translocation,
@@ -141,6 +141,7 @@ class TestNodePredicates(unittest.TestCase):
     def test_p1_active(self):
         """cat(p(HGNC:HSD11B1)) increases deg(a(CHEBI:cortisol))"""
         g = BELGraph()
+        g.annotation_pattern['Species'] = r'\d+'
 
         u = protein(name='HSD11B1', namespace='HGNC')
         v = abundance(name='cortisol', namespace='CHEBI', identifier='17650')
@@ -149,7 +150,7 @@ class TestNodePredicates(unittest.TestCase):
             u,
             v,
             citation={
-                CITATION_DB: CITATION_TYPE_ONLINE, CITATION_IDENTIFIER: 'https://www.ncbi.nlm.nih.gov/gene/3290'
+                NAMESPACE: CITATION_TYPE_URL, IDENTIFIER: 'https://www.ncbi.nlm.nih.gov/gene/3290'
             },
             evidence="Entrez Gene Summary: Human: The protein encoded by this gene is a microsomal enzyme that "
                      "catalyzes the conversion of the stress hormone cortisol to the inactive metabolite cortisone. "
@@ -158,8 +159,8 @@ class TestNodePredicates(unittest.TestCase):
                      "gene has been associated with obesity and insulin resistance in children. Two transcript "
                      "variants encoding the same protein have been found for this gene.",
             annotations={'Species': '9606'},
-            subject_modifier=activity('cat'),
-            object_modifier=degradation()
+            source_modifier=activity('cat'),
+            target_modifier=degradation(),
         )
 
         self.assertFalse(is_translocated(g, u))
@@ -173,6 +174,7 @@ class TestNodePredicates(unittest.TestCase):
     def test_object_has_translocation(self):
         """p(HGNC: EGF) increases tloc(p(HGNC: VCP), GO:0005634, GO:0005737)"""
         g = BELGraph()
+        g.annotation_pattern['Species'] = r'\d+'
         u = protein(name='EFG', namespace='HGNC')
         v = protein(name='VCP', namespace='HGNC')
 
@@ -183,7 +185,7 @@ class TestNodePredicates(unittest.TestCase):
             evidence="Although found predominantly in the cytoplasm and, less abundantly, in the nucleus, VCP can be "
                      "translocated from the nucleus after stimulation with epidermal growth factor.",
             annotations={'Species': '9606'},
-            object_modifier=translocation(
+            target_modifier=translocation(
                 from_loc=Entity(namespace='GO', identifier='0005634'),
                 to_loc=Entity(namespace='GO', identifier='0005737'),
             )
@@ -204,6 +206,8 @@ class TestNodePredicates(unittest.TestCase):
     def test_object_has_secretion(self):
         """p(MGI:Il4) increases sec(p(MGI:Cxcl1))"""
         g = BELGraph()
+        g.annotation_pattern['Species'] = r'\d+'
+        g.annotation_pattern['MeSH'] = '.*'
         u = protein(name='Il4', namespace='MGI')
         v = protein(name='Cxcl1', namespace='MGI')
 
@@ -217,7 +221,7 @@ class TestNodePredicates(unittest.TestCase):
                      'expression and cellular infiltration....Recombinant cytokines were used, ... to treat naive '
                      'BALB/c mice.',
             annotations={'Species': '10090', 'MeSH': 'bronchoalveolar lavage fluid'},
-            object_modifier=secretion()
+            target_modifier=secretion(),
         )
 
         self.assertFalse(is_translocated(g, u))
@@ -235,6 +239,8 @@ class TestNodePredicates(unittest.TestCase):
     def test_subject_has_secretion(self):
         """sec(p(MGI:S100b)) increases a(CHEBI:"nitric oxide")"""
         g = BELGraph()
+        g.annotation_pattern['Species'] = r'\d+'
+        g.annotation_pattern['Cell'] = r'.*'
         u = protein(name='S100b', namespace='MGI')
         v = abundance(name='nitric oxide', namespace='CHEBI')
 
@@ -245,7 +251,7 @@ class TestNodePredicates(unittest.TestCase):
             evidence='S100B protein is also secreted by astrocytes and acts on these cells to stimulate nitric oxide '
                      'secretion in an autocrine manner.',
             annotations={'Species': '10090', 'Cell': 'astrocyte'},
-            subject_modifier=secretion()
+            source_modifier=secretion()
         )
 
         self.assertTrue(is_translocated(g, u))
@@ -419,8 +425,8 @@ class TestEdgePredicate(unittest.TestCase):
         self.assertTrue(has_provenance({CITATION: {}, EVIDENCE: ''}))
 
     def test_has_pubmed(self):
-        self.assertTrue(has_pubmed({CITATION: {CITATION_DB: CITATION_TYPE_PUBMED}}))
-        self.assertFalse(has_pubmed({CITATION: {CITATION_DB: CITATION_TYPE_ONLINE}}))
+        self.assertTrue(has_pubmed({CITATION: {NAMESPACE: CITATION_TYPE_PUBMED}}))
+        self.assertFalse(has_pubmed({CITATION: {NAMESPACE: CITATION_TYPE_URL}}))
         self.assertFalse(has_pubmed({}))
 
     def test_has_authors(self):
@@ -481,37 +487,37 @@ class TestEdgePredicate(unittest.TestCase):
         self.assertTrue(is_increase_or_decrease(g, p3, p4, 0))
 
     def test_has_degradation(self):
-        self.assertTrue(edge_has_degradation({SUBJECT: {MODIFIER: DEGRADATION}}))
-        self.assertTrue(edge_has_degradation({OBJECT: {MODIFIER: DEGRADATION}}))
+        self.assertTrue(edge_has_degradation({SOURCE_MODIFIER: {MODIFIER: DEGRADATION}}))
+        self.assertTrue(edge_has_degradation({TARGET_MODIFIER: {MODIFIER: DEGRADATION}}))
 
-        self.assertFalse(edge_has_degradation({SUBJECT: {MODIFIER: TRANSLOCATION}}))
-        self.assertFalse(edge_has_degradation({SUBJECT: {MODIFIER: ACTIVITY}}))
-        self.assertFalse(edge_has_degradation({SUBJECT: {LOCATION: None}}))
-        self.assertFalse(edge_has_degradation({OBJECT: {MODIFIER: TRANSLOCATION}}))
-        self.assertFalse(edge_has_degradation({OBJECT: {MODIFIER: ACTIVITY}}))
-        self.assertFalse(edge_has_degradation({OBJECT: {LOCATION: None}}))
+        self.assertFalse(edge_has_degradation({SOURCE_MODIFIER: {MODIFIER: TRANSLOCATION}}))
+        self.assertFalse(edge_has_degradation({SOURCE_MODIFIER: {MODIFIER: ACTIVITY}}))
+        self.assertFalse(edge_has_degradation({SOURCE_MODIFIER: {LOCATION: None}}))
+        self.assertFalse(edge_has_degradation({TARGET_MODIFIER: {MODIFIER: TRANSLOCATION}}))
+        self.assertFalse(edge_has_degradation({TARGET_MODIFIER: {MODIFIER: ACTIVITY}}))
+        self.assertFalse(edge_has_degradation({TARGET_MODIFIER: {LOCATION: None}}))
 
     def test_has_translocation(self):
-        self.assertTrue(edge_has_translocation({SUBJECT: {MODIFIER: TRANSLOCATION}}))
-        self.assertTrue(edge_has_translocation({OBJECT: {MODIFIER: TRANSLOCATION}}))
+        self.assertTrue(edge_has_translocation({SOURCE_MODIFIER: {MODIFIER: TRANSLOCATION}}))
+        self.assertTrue(edge_has_translocation({TARGET_MODIFIER: {MODIFIER: TRANSLOCATION}}))
 
-        self.assertFalse(edge_has_translocation({SUBJECT: {MODIFIER: ACTIVITY}}))
-        self.assertFalse(edge_has_translocation({SUBJECT: {LOCATION: None}}))
-        self.assertFalse(edge_has_translocation({SUBJECT: {MODIFIER: DEGRADATION}}))
-        self.assertFalse(edge_has_translocation({OBJECT: {MODIFIER: ACTIVITY}}))
-        self.assertFalse(edge_has_translocation({OBJECT: {LOCATION: None}}))
-        self.assertFalse(edge_has_translocation({OBJECT: {MODIFIER: DEGRADATION}}))
+        self.assertFalse(edge_has_translocation({SOURCE_MODIFIER: {MODIFIER: ACTIVITY}}))
+        self.assertFalse(edge_has_translocation({SOURCE_MODIFIER: {LOCATION: None}}))
+        self.assertFalse(edge_has_translocation({SOURCE_MODIFIER: {MODIFIER: DEGRADATION}}))
+        self.assertFalse(edge_has_translocation({TARGET_MODIFIER: {MODIFIER: ACTIVITY}}))
+        self.assertFalse(edge_has_translocation({TARGET_MODIFIER: {LOCATION: None}}))
+        self.assertFalse(edge_has_translocation({TARGET_MODIFIER: {MODIFIER: DEGRADATION}}))
 
     def test_has_activity(self):
-        self.assertTrue(edge_has_activity({SUBJECT: {MODIFIER: ACTIVITY}}))
-        self.assertTrue(edge_has_activity({OBJECT: {MODIFIER: ACTIVITY}}))
+        self.assertTrue(edge_has_activity({SOURCE_MODIFIER: {MODIFIER: ACTIVITY}}))
+        self.assertTrue(edge_has_activity({TARGET_MODIFIER: {MODIFIER: ACTIVITY}}))
 
-        self.assertFalse(edge_has_activity({SUBJECT: {MODIFIER: TRANSLOCATION}}))
-        self.assertFalse(edge_has_activity({OBJECT: {MODIFIER: TRANSLOCATION}}))
-        self.assertFalse(edge_has_activity({SUBJECT: {LOCATION: None}}))
-        self.assertFalse(edge_has_activity({SUBJECT: {MODIFIER: DEGRADATION}}))
-        self.assertFalse(edge_has_activity({OBJECT: {LOCATION: None}}))
-        self.assertFalse(edge_has_activity({OBJECT: {MODIFIER: DEGRADATION}}))
+        self.assertFalse(edge_has_activity({SOURCE_MODIFIER: {MODIFIER: TRANSLOCATION}}))
+        self.assertFalse(edge_has_activity({TARGET_MODIFIER: {MODIFIER: TRANSLOCATION}}))
+        self.assertFalse(edge_has_activity({SOURCE_MODIFIER: {LOCATION: None}}))
+        self.assertFalse(edge_has_activity({SOURCE_MODIFIER: {MODIFIER: DEGRADATION}}))
+        self.assertFalse(edge_has_activity({TARGET_MODIFIER: {LOCATION: None}}))
+        self.assertFalse(edge_has_activity({TARGET_MODIFIER: {MODIFIER: DEGRADATION}}))
 
     def test_has_annotation(self):
         self.assertFalse(edge_has_annotation({}, 'Subgraph'))
