@@ -14,7 +14,7 @@ from pybel.struct.filters.edge_predicate_builders import (
     _annotation_dict_all_filter, _annotation_dict_any_filter, build_annotation_dict_all_filter,
     build_annotation_dict_any_filter,
 )
-from pybel.struct.filters.edge_predicates import keep_edge_permissive
+from pybel.struct.filters.edge_predicates import true_edge_predicate
 from pybel.struct.filters.node_predicates import true_node_predicate
 from pybel.struct.filters.typing import EdgeIterator
 from pybel.testing.utils import n
@@ -75,11 +75,11 @@ class TestNodeFilters(unittest.TestCase):
         self.assertEqual({(1, 2)}, edges)
 
     def test_keep_edge_permissive(self):
-        edges = make_edge_iterator_set(filter_edges(self.graph, keep_edge_permissive))
+        edges = make_edge_iterator_set(filter_edges(self.graph, true_edge_predicate))
         self.assertEqual({(1, 2)}, edges)
 
     def test_keep_edge_unpermissive(self):
-        keep_edge_restrictive = invert_edge_predicate(keep_edge_permissive)
+        keep_edge_restrictive = invert_edge_predicate(true_edge_predicate)
         edges = make_edge_iterator_set(filter_edges(self.graph, keep_edge_restrictive))
         self.assertEqual(set(), edges)
 
@@ -88,7 +88,7 @@ class TestNodeFilters(unittest.TestCase):
         self.assertEqual(({(1, 2)}), edges)
 
     def test_concatenate_single_edge_filter(self):
-        edges = make_edge_iterator_set(filter_edges(self.graph, [keep_edge_permissive]))
+        edges = make_edge_iterator_set(filter_edges(self.graph, [true_edge_predicate]))
         self.assertEqual({(1, 2)}, edges)
 
     def test_concatenate_multiple_edge_filter(self):
@@ -158,13 +158,14 @@ class TestEdgeFilters(unittest.TestCase):
 
     def test_any_filter(self):
         graph = BELGraph()
+        graph.annotation_list['A'] = set('12345')
         graph.add_increases(Protein(n(), n()), Protein(n(), n()), citation=n(), evidence=n(), annotations={
             'A': {'1', '2', '3'}
         })
 
-        self.assertEqual(1, count_passed_edge_filter(graph, build_annotation_dict_any_filter({'A': {'1'}})))
-        self.assertEqual(1, count_passed_edge_filter(graph, build_annotation_dict_any_filter({'A': {'1', '2'}})))
-        self.assertEqual(1, count_passed_edge_filter(graph, build_annotation_dict_any_filter({'A': {'1', '2', '3'}})))
+        self.assertEqual(1, count_passed_edge_filter(graph, build_annotation_dict_any_filter(graph._clean_annotations({'A': {'1'}}))))
+        self.assertEqual(1, count_passed_edge_filter(graph, build_annotation_dict_any_filter(graph._clean_annotations({'A': {'1', '2'}}))))
+        self.assertEqual(1, count_passed_edge_filter(graph, build_annotation_dict_any_filter(graph._clean_annotations({'A': {'1', '2', '3'}}))))
 
     def test_b(self):
         self.assertTrue(_annotation_dict_all_filter(
@@ -225,37 +226,36 @@ class TestEdgeFilters(unittest.TestCase):
 
     def test_all_filter(self):
         graph = BELGraph()
+        graph.annotation_list['A'] = set('12345')
         graph.add_increases(Protein(n(), n()), Protein(n(), n()), citation=n(), evidence=n(), annotations={
-            'A': {'1', '2', '3'}
+            'A': {'1', '2', '3'},
         })
 
-        self.assertEqual(1, count_passed_edge_filter(graph, build_annotation_dict_all_filter({'A': {'1'}})))
-        self.assertEqual(1, count_passed_edge_filter(graph, build_annotation_dict_all_filter({'A': {'1', '2'}})))
-        self.assertEqual(1, count_passed_edge_filter(graph, build_annotation_dict_all_filter({'A': {'1', '2', '3'}})))
+        self.assertEqual(1, count_passed_edge_filter(graph, build_annotation_dict_all_filter(graph._clean_annotations({'A': {'1'}}))))
+        self.assertEqual(1, count_passed_edge_filter(graph, build_annotation_dict_all_filter(graph._clean_annotations({'A': {'1', '2'}}))))
+        self.assertEqual(1, count_passed_edge_filter(graph, build_annotation_dict_all_filter(graph._clean_annotations({'A': {'1', '2', '3'}}))))
         self.assertEqual(0,
-                         count_passed_edge_filter(graph, build_annotation_dict_all_filter({'A': {'1', '2', '3', '4'}})))
-        self.assertEqual(0, count_passed_edge_filter(graph, build_annotation_dict_all_filter({'A': {'4'}})))
+                         count_passed_edge_filter(graph, build_annotation_dict_all_filter(graph._clean_annotations({'A': {'1', '2', '3', '4'}}))))
+        self.assertEqual(0, count_passed_edge_filter(graph, build_annotation_dict_all_filter(graph._clean_annotations({'A': {'4'}}))))
 
     def test_all_filter_dict(self):
         graph = BELGraph()
-        graph.add_edge(1, 2, annotations={
-            'A': {'1', '2', '3'}
+        graph.annotation_list['A'] = set('12345')
+        a, b = Protein(namespace='hgnc', identifier='1', name='A'), Protein(namespace='hgnc', identifier='2', name='B')
+        graph.add_increases(a, b, citation=n(), evidence=n(), annotations={
+            'A': {'1', '2', '3'},
         })
 
-        self.assertEqual(1, count_passed_edge_filter(graph, build_annotation_dict_all_filter({'A': {'1': True}})))
-        self.assertEqual(1, count_passed_edge_filter(graph, build_annotation_dict_all_filter({
+        self.assertEqual(1, count_passed_edge_filter(graph, build_annotation_dict_all_filter(graph._clean_annotations({'A': {'1': True}}))))
+        self.assertEqual(1, count_passed_edge_filter(graph, build_annotation_dict_all_filter(graph._clean_annotations({
             'A': {'1': True, '2': True}
-        })))
-        self.assertEqual(1, count_passed_edge_filter(graph, build_annotation_dict_all_filter({
+        }))))
+        self.assertEqual(1, count_passed_edge_filter(graph, build_annotation_dict_all_filter(graph._clean_annotations({
             'A': {'1': True, '2': True, '3': True}
-        })))
-        self.assertEqual(0, count_passed_edge_filter(graph, build_annotation_dict_all_filter({
+        }))))
+        self.assertEqual(0, count_passed_edge_filter(graph, build_annotation_dict_all_filter(graph._clean_annotations({
             'A': {'1': True, '2': True, '3': True, '4': True}
-        })))
-        self.assertEqual(0, count_passed_edge_filter(graph, build_annotation_dict_all_filter({
+        }))))
+        self.assertEqual(0, count_passed_edge_filter(graph, build_annotation_dict_all_filter(graph._clean_annotations({
             'A': {'4': True}
-        })))
-
-
-if __name__ == '__main__':
-    unittest.main()
+        }))))
